@@ -6,7 +6,7 @@ import logging
 import re
 from types import ModuleType
 from typing import Any, Dict, List, Optional
-from con_duct.__main__ import DUCT_OUTPUT_PREFIX, SummaryFormatter
+from con_duct.__main__ import DUCT_OUTPUT_PREFIX, SummaryFormatter, __schema_version__
 from con_duct.utils import parse_version
 
 try:
@@ -46,6 +46,7 @@ NON_TRANSFORMED_FIELDS: List[str] = [
     "hostname",
     "info",
     "logs_prefix",
+    "message",
     "num_samples",
     "num_reports",
     "prefix",
@@ -55,6 +56,7 @@ NON_TRANSFORMED_FIELDS: List[str] = [
     "uid",
     "usage",
     "user",
+    "working_directory",
 ]
 
 LS_FIELD_CHOICES: List[str] = (
@@ -81,6 +83,7 @@ def load_duct_runs(
                         f"is below minimum schema version {MINIMUM_SCHEMA_VERSION}."
                     )
                     continue
+                ensure_compliant_schema(this)
                 if eval_filter is not None and not (
                     eval_results := eval(eval_filter, _flatten_dict(this), dict(re=re))
                 ):
@@ -92,11 +95,28 @@ def load_duct_runs(
                     continue
 
                 loaded.append(this)
+            except json.JSONDecodeError as exc:
+                # Check if this is truly an empty file (no meaningful content)
+                if exc.pos == 0 and not exc.doc.strip():
+                    lgr.debug("Skipping empty file %s", info_file)
+                else:
+                    lgr.warning("Failed to load file %s: %s", file, exc)
             except Exception as exc:
                 lgr.warning("Failed to load file %s: %s", file, exc)
     return loaded
 
 
+def ensure_compliant_schema(info_dict: dict) -> None:
+    if parse_version(info_dict["schema_version"]) == parse_version(__schema_version__):
+        return
+    # working_directory added in 0.2.1
+    if parse_version(info_dict["schema_version"]) < parse_version("0.2.1"):
+        info_dict["execution_summary"]["working_directory"] = ""
+    # message field added in 0.2.2
+    if parse_version(info_dict["schema_version"]) < parse_version("0.2.2"):
+        info_dict["message"] = ""
+
+
 def process_run_data(
     run_data_list: List[Dict[str, Any]], fields: List[str], formatter: SummaryFormatter
 ) -> List[OrderedDict[str, Any]]:
@@ -148,14 +168,46 @@ def _format_row(
     return transformed
 
 
-def pyout_ls(run_data_list: List[OrderedDict[str, Any]]) -> None:
+def pyout_ls(run_data_list: List[OrderedDict[str, Any]], enable_colors: bool) -> None:
     """Generate and print a tabular table using pyout."""
     if pyout is None:
         raise RuntimeError("pyout is required for this output format.")
 
+    color_styles = {
+        "E": dict(
+            color=dict(
+                re_lookup=[
+                    ["^0$", "green"],  # if exactly "0", then green
+                    [".*", "red"],  # anything else gets red
+                ]
+            )
+        ),
+        "N": dict(
+            color=dict(
+                re_lookup=[
+                    [f"^{SummaryFormatter.NONE}", "red"],  # if starts with NONE
+                    [".*", "green"],
+                ]
+            )
+        ),
+    }
+    # S is humansize, conversion done, coloring same as N
+    color_styles["S"] = color_styles["N"]
+
+    pattern = re.compile(r"!([A-Z])")
+    conversion_map = (
+        {
+            k: color_styles[match.group(1)]
+            for k, v in VALUE_TRANSFORMATION_MAP.items()
+            if (match := pattern.search(v))
+        }
+        if enable_colors
+        else {}
+    )
     with pyout.Tabular(
         style=dict(
             header_=dict(bold=True, transform=str.upper),
+            **conversion_map,
         ),
         mode="final",
     ) as table:
@@ -164,19 +216,20 @@ def pyout_ls(run_data_list: List[OrderedDict[str, Any]]) -> None:
 
 
 def ls(args: argparse.Namespace) -> int:
-
     if not args.paths:
         pattern = f"{DUCT_OUTPUT_PREFIX[:DUCT_OUTPUT_PREFIX.index('{')]}*"
         args.paths = [p for p in glob.glob(pattern)]
 
-    info_files = [path for path in args.paths if path.endswith("info.json")]
-    run_data_raw = load_duct_runs(info_files, args.eval_filter)
-    formatter = SummaryFormatter(enable_colors=args.colors)
-    output_rows = process_run_data(run_data_raw, args.fields, formatter)
-
     if args.format == "auto":
         args.format = "summaries" if pyout is None else "pyout"
 
+    formatter = SummaryFormatter(
+        enable_colors=False if args.format == "pyout" else args.colors
+    )
+    info_files = [path for path in args.paths if path.endswith("info.json")]
+    run_data_raw = load_duct_runs(info_files, args.eval_filter)
+    output_rows = process_run_data(run_data_raw, args.fields, formatter)
+
     if args.format == "summaries":
         for row in output_rows:
             for col, value in row.items():
@@ -186,7 +239,7 @@ def ls(args: argparse.Namespace) -> int:
     elif args.format == "pyout":
         if pyout is None:
             raise RuntimeError("Install pyout for pyout output")
-        pyout_ls(output_rows)
+        pyout_ls(output_rows, args.colors)
     elif args.format == "json":
         print(json.dumps(output_rows))
     elif args.format == "json_pp":
