@@ -1,3 +1,4 @@
+import logging
 import os
 from pathlib import Path
 from typing import Generator
@@ -22,6 +23,22 @@ def set_test_config() -> Generator:
             del os.environ[k]
 
 
+@pytest.fixture(autouse=True)
+def reset_logger_state() -> Generator:
+    """Automatically reset logger state after each test.
+
+    The execute() function can disable the logger globally when quiet=True
+    or log_level="NONE", which affects subsequent tests. This fixture ensures
+    the logger is reset to default state after each test.
+    """
+    import con_duct.__main__ as main_module
+
+    yield
+
+    main_module.lgr.disabled = False
+    main_module.lgr.setLevel(logging.INFO)
+
+
 @pytest.fixture
 def temp_output_dir(tmp_path: Path) -> str:
     # Append path separator so that value is recognized as a directory when
